diff hgext/largefiles/lfcommands.py @ 18574:4db9e31ae605

largefiles: docstrings for verify methods
author Mads Kiilerich <mads@kiilerich.com>
date Fri, 08 Feb 2013 13:08:25 +0100
parents 65cec7fa5472
children c2d079387b2c
line wrap: on
line diff
--- a/hgext/largefiles/lfcommands.py	Fri Feb 08 13:00:08 2013 +0100
+++ b/hgext/largefiles/lfcommands.py	Fri Feb 08 13:08:25 2013 +0100
@@ -368,9 +368,9 @@
     ui.progress(_('uploading largefiles'), None)
 
 def verifylfiles(ui, repo, all=False, contents=False):
-    '''Verify that every big file revision in the current changeset
+    '''Verify that every largefile revision in the current changeset
     exists in the central store.  With --contents, also verify that
     the contents of each big file revision are correct (SHA-1 hash
     matches the revision ID).  With --all, check every changeset in
     this repository.'''
     if all:
@@ -368,9 +368,9 @@
     exists in the central store.  With --contents, also verify that
-    the contents of each big file revision are correct (SHA-1 hash
+    the contents of each local largefile file revision are correct (SHA-1 hash
     matches the revision ID).  With --all, check every changeset in
     this repository.'''